/*
 * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
 *		Gediminas Paulauskas <menesis@gtranslator.org>
 *
 * gtranslator is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 * gtranslator is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef GTR_MENUS_H
#define GTR_MENUS_H 1

#include <libgnomeui/gnome-app.h>
#include <libgnomeui/gnome-app-helper.h>

extern GnomeUIInfo the_menus[];

extern GnomeUIInfo the_file_menu[];
extern GnomeUIInfo the_last_files_menus[];
extern GnomeUIInfo the_edit_menu[];
extern GnomeUIInfo the_views_menu[];
extern GnomeUIInfo the_messages_menu[];
extern GnomeUIInfo the_msg_status_menu[];
extern GnomeUIInfo the_settings_menu[];
extern GnomeUIInfo the_help_menu[];

extern GnomeUIInfo the_toolbar[];
extern GnomeUIInfo the_navibar[];

extern GnomeUIInfo the_main_popup_menu[];

#endif
